"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.paste = paste;

var _dom = require("@testing-library/dom");

var _utils = require("./utils");

function paste(clipboardData, options) {
  var _options$document, _doc$activeElement;

  const doc = (_options$document = options == null ? void 0 : options.document) != null ? _options$document : document;
  const target = (_doc$activeElement = doc.activeElement) != null ? _doc$activeElement :
  /* istanbul ignore next */
  doc.body;
  const data = typeof clipboardData === 'string' ? getClipboardDataFromString(clipboardData) : clipboardData;
  return data ? pasteImpl(target, data) : readClipboardDataFromClipboardApi(doc).then(dt => pasteImpl(target, dt));
}

function pasteImpl(target, clipboardData) {
  _dom.fireEvent.paste(target, {
    clipboardData
  });

  if ((0, _utils.isEditable)(target)) {
    const data = clipboardData.getData('text').substr(0, (0, _utils.getSpaceUntilMaxLength)(target));

    if (data) {
      var _prepareInput;

      (_prepareInput = (0, _utils.prepareInput)(data, target, 'insertFromPaste')) == null ? void 0 : _prepareInput.commit();
    }
  }
}

function getClipboardDataFromString(text) {
  const dt = (0, _utils.createDataTransfer)();
  dt.setData('text', text);
  return dt;
}

async function readClipboardDataFromClipboardApi(document) {
  var _document$defaultView;

  const clipboard = (_document$defaultView = document.defaultView) == null ? void 0 : _document$defaultView.navigator.clipboard;
  const items = clipboard && (await clipboard.read());

  if (!items) {
    throw new Error('`userEvent.paste()` without `clipboardData` requires the `ClipboardAPI` to be available.');
  }

  const dt = (0, _utils.createDataTransfer)();

  for (const item of items) {
    for (const type of item.types) {
      dt.setData(type, await item.getType(type).then(b => (0, _utils.readBlobText)(b)));
    }
  }

  return dt;
}